#
# The iasl in nixpkgs is no longer able to build coreboot releases old
# enough to support kgpe-d16, so we package a version that is able to.
#
# The contents of this file are based on an old version of
# `nixpkgs/pkgs/tools/system/acpica-tools/default.nix`.
#

{ stdenv
, fetchurl
, bison
, flex
, fetchpatch
}:

stdenv.mkDerivation rec {
  name = "iasl-${version}";
  version = "20180531";

  src = fetchurl {
    url = "https://acpica.org/sites/acpica/files/acpica-unix-${version}.tar.gz";
    sha256 = "sha256-j2zcqkA5wrPbFBEX7IIj8OEpdoS4q0eDniEb3a0CdmU=";
  };

  # These two commits from https://github.com/acpica/acpica/pull/566
  # are required to get older versions of iasl to build with newer
  # compilers/binutils
  patches = [
    (fetchurl {
      url = "https://github.com/acpica/acpica/commit/fa605f87907370b40e91e1eb90a284fd6177df59.patch";
      hash = "sha256-CnnJRsGe6oHc5w0CzTtCyiowmfHfi4Dri79VcaS1Sd4=";
    })
    (fetchpatch {
      url = "https://github.com/acpica/acpica/commit/01ab8c6dd686139d0ccc4651cc90387081b59e09.patch";
      excludes = [ "source/compiler/dtcompilerparser.l" ];
      hash = "sha256-WOThi/WgZWwJH4Iy32SltTiSew2RJBrW7tPhQ7r7tI8=";
    })
  ];

  NIX_CFLAGS_COMPILE = "-O3 -w";

  hardeningDisable = [ "all" ];

  buildFlags = "iasl";

  buildInputs = [ bison flex ];

  installPhase =
    ''
      install -d $out/bin
      install generate/unix/bin*/iasl $out/bin
    '';

  meta = {
    description = "Intel ACPI Compiler";
    homepage = http://www.acpica.org/;
  };
}
